@@ -115,7 +115,7 @@ CartesianGuides <- function(widget, ggplotPanelParams, swapAxes, theme){
   }
 
   # set border if it has
-  if(length(theme$panel.border) != 0) {
+  if(!is.element_blank(theme$panel.border) && !is.null(theme$panel.border)) {
     panel.border_color <- hex6to12(theme$panel.border$colour)
     borderGroup <- loon::l_layer_group(widget, "borders", parent = guidesGroup)
     borderLayer <- loon::l_layer_lines(widget,
