@@ -4,7 +4,7 @@ ggCompound <- function(plots,
                        colour.bg = loon::l_getOption("background")) {
 
   if(setBackground) {
-    do.call(patchwork::wrap_plots, plots) &
+    do.call(patchwork::wrap_plots, plots) +
       ggplot2::theme(
         plot.background = ggplot2::element_rect(fill = fill.bg,
                                                 colour = colour.bg)
