@@ -74,7 +74,7 @@ ggHistogramFacets <- function(widget, asAes = TRUE, selectedOnTop = TRUE,
         ggplot2::aes(x = x, fill = fill)
       } else {
         ggplot2::aes(x = x, fill = fill,
-                     y = ..density..)
+                     y = after_stat(density))
         # the layout would be different from the loon one
       },
       color = color,
@@ -122,7 +122,7 @@ ggHistogram <- function(widget, asAes = TRUE, selectedOnTop = TRUE,
           ggplot2::aes(x = x, fill = fill)
         } else {
           ggplot2::aes(x = x, fill = fill,
-                       y = ..density..)
+                       y = after_stat(density))
           # the layout would be different from the loon one
         },
         color = color,
