@@ -129,7 +129,7 @@
 loon2ggplot <- function(target, asAes = TRUE, selectedOnTop = TRUE,
                         showNearestColor = FALSE, ...) {
 
-  if(ggplot2::is.ggplot(target) || is.ggmatrix(target)) {
+  if(ggplot2::is_ggplot(target) || is.ggmatrix(target)) {
     error_info <- deparse(substitute(target))
     stop(
       "Target should be a loon object. Maybe you want to call `ggplot2loon(",
@@ -320,24 +320,24 @@ cartesian_gg <- function(target, ggObj, setLimits = TRUE) {
     ggplot2::ggtitle(label = if(title == "") NULL else title) +
     ggplot2::theme(
       axis.ticks = if(showScales) ggplot2::element_line() else ggplot2::element_blank(),
-      axis.text.x = if(showScales) ggplot2::element_text(size = scalesFont$size, family = scalesFont$family, face = scalesFont$face) else ggplot2::element_blank(),
-      axis.text.y = if(showScales) ggplot2::element_text(size = scalesFont$size, family = scalesFont$family, face = scalesFont$face) else ggplot2::element_blank(),
-      axis.title = if(showLabels) ggplot2::element_text(size = titleFont$size, family = titleFont$family, face = titleFont$face) else ggplot2::element_blank(),
-      axis.title.x = if(showLabels) ggplot2::element_text(size = xlabelFont$size, family = xlabelFont$family, face = xlabelFont$face) else ggplot2::element_blank(),
-      axis.title.y = if(showLabels) ggplot2::element_text(size = ylabelFont$size, family = ylabelFont$family, face = ylabelFont$face) else ggplot2::element_blank(),
+      axis.text.x = if(showScales) ggplot2::element_text(size = as.numeric(scalesFont$size), family = scalesFont$family, face = scalesFont$face) else ggplot2::element_blank(),
+      axis.text.y = if(showScales) ggplot2::element_text(size = as.numeric(scalesFont$size), family = scalesFont$family, face = scalesFont$face) else ggplot2::element_blank(),
+      axis.title = if(showLabels) ggplot2::element_text(size = as.numeric(titleFont$size), family = titleFont$family, face = titleFont$face) else ggplot2::element_blank(),
+      axis.title.x = if(showLabels) ggplot2::element_text(size = as.numeric(xlabelFont$size), family = xlabelFont$family, face = xlabelFont$face) else ggplot2::element_blank(),
+      axis.title.y = if(showLabels) ggplot2::element_text(size = as.numeric(ylabelFont$size), family = ylabelFont$family, face = ylabelFont$face) else ggplot2::element_blank(),
       plot.background = ggplot2::element_rect(fill = as_hex6color(widget['background'])),
       plot.title = ggplot2::element_text(hjust = 0.5),
       panel.background = ggplot2::element_rect(fill = guidesBackGround),
-      panel.grid.major = ggplot2::element_line(size = 1,
+      panel.grid.major = ggplot2::element_line(linewidth = 1,
                                                linetype = 'solid',
                                                colour = as_hex6color(widget['guidelines'])),
-      panel.grid.minor = ggplot2::element_line(size = 0.5,
+      panel.grid.minor = ggplot2::element_line(linewidth = 0.5,
                                                linetype = 'solid',
                                                colour = as_hex6color(widget['guidelines'])),
       panel.border = if(sum(margins, na.rm = TRUE) > 0) {
         ggplot2::element_rect(colour = as_hex6color(widget['foreground']),
                               fill = NA,
-                              size = 0.5)
+                              linewidth = 0.5)
       } else {
         ggplot2::element_blank()
       },
@@ -448,7 +448,7 @@ loon2ggplot.l_layer_line <- function(target, asAes = TRUE, selectedOnTop = TRUE,
       data = data,
       mapping = ggplot2::aes(x = x, y = y),
       colour = states$color,
-      size = as_ggplot_size(states$linewidth, "lines")
+      linewidth = as_ggplot_size(states$linewidth, "lines")
     )
 }
 
