@@ -160,7 +160,7 @@ polarGuides <- function(widget, ggplotPanelParams, swapAxes, theme){
     }
   }
   # set border if it has
-  if(length(theme$panel.border) != 0) {
+  if(length(theme$panel.border) > 0 && !is.element_blank(theme$panel.border)) {
     panel.border_color <- hex6to12(theme$panel.border$colour)
     borderGroup <- loon::l_layer_group(widget, "borders", parent = guidesGroup)
     borderLayer <- loon::l_layer_lines(widget,
