@@ -97,7 +97,7 @@ scale_multi <- function(trans = scaleBox(center = TRUE), ...) {
 #' x, where 'numeric-alike' means that \code{as.numeric(.)} will be applied successfully
 #' if \code{is.numeric(.)} is not true.
 #' @return A \code{trans} object
-#' @seealso \code{\link{l_scale3D}}
+#' @seealso \code{\link[loon]{l_scale3D}}
 #' @export
 scaleBox <- function(center = TRUE) {
   scales::trans_new(
@@ -125,13 +125,16 @@ scale_z_continuous <- function(name = ggplot2::waiver(), breaks = ggplot2::waive
                                guide = ggplot2::waiver(), position = "right",
                                sec.axis = ggplot2::waiver()) {
 
-  sc <- ggplot2::continuous_scale(c("z", "zmin", "zmax",
+  sc <- ggplot2::continuous_scale(aesthetics = c("z", "zmin", "zmax",
                                     "zend", "zintercept", "zmin_final",
                                     "zmax_final", "zlower", "zmiddle",
-                                    "zupper", "z0"), "position_c", identity,
+                                    "zupper", "z0"),
+                                  palette = identity,
                                   name = name, breaks = breaks, n.breaks = n.breaks, minor_breaks = minor_breaks,
                                   labels = labels, limits = limits, expand = expand, oob = oob,
-                                  na.value = na.value, trans = trans, guide = guide, position = position,
+                                  na.value = na.value,
+                                  # trans = trans,
+                                  guide = guide, position = position,
                                   super = ggplot2::ScaleContinuousPosition)
   set_sec_axis(sec.axis, sc)
 }
